@@ -1,155 +1,108 @@
 package Bot::Cobalt::Conf;
-our $VERSION = '0.016002';
-
+$Bot::Cobalt::Conf::VERSION = '0.017001';
+use strictures 2;
 use Carp;
-use Moo;
 
-use strictures 1;
-
-use Bot::Cobalt::Common qw/:types/;
+use Bot::Cobalt::Common ':types';
 
 use Bot::Cobalt::Conf::File::Core;
 use Bot::Cobalt::Conf::File::Channels;
 use Bot::Cobalt::Conf::File::Plugins;
 
-use File::Spec;
+use Path::Tiny;
+use Types::Path::Tiny -types;
 
-use Scalar::Util qw/blessed/;
+use Scalar::Util 'blessed';
 
 
-use namespace::clean -except => 'meta';
+use Moo;
 
-
-
-has 'etc'   => (
-  required => 1,
-
-  is  => 'rw',
-  isa => Str,
+has etc => (
+  required  => 1,
+  is        => 'rw',
+  isa       => Path,
+  coerce    => 1,
 );
 
-has 'debug' => (
-  is  => 'rw',
-  isa => Bool,
-
-  default => sub { 0 }
+has debug => (
+  is        => 'rw',
+  isa       => Bool,
+  builder   => sub { 0 }
 );
 
-has 'path_to_core_cf' => (
-  lazy => 1,
-
-  is  => 'rwp',
-  isa => Str,
-
-  default => sub {
-    my ($self) = @_;
-
-    File::Spec->catfile(
-      $self->etc,
-      'cobalt.conf'
-    )
+has path_to_core_cf => (
+  lazy      => 1,
+  is        => 'rwp',
+  isa       => Path,
+  coerce    => 1,
+  builder   => sub {
+    path( shift->etc .'/cobalt.conf' )
   },
 );
 
-has 'path_to_channels_cf' => (
-  lazy => 1,
-
-  is  => 'rwp',
-  isa => Str,
-
-  default => sub {
-    my ($self) = @_;
-
-    File::Spec->catfile(
-      $self->etc,
-      'channels.conf'
-    )
+has path_to_channels_cf => (
+  lazy      => 1,
+  is        => 'rwp',
+  isa       => Path,
+  coerce    => 1,
+  builder   => sub {
+    path( shift->etc .'/channels.conf' )
   },
 );
 
-has 'path_to_plugins_cf' => (
-  lazy => 1,
-
-  is  => 'rwp',
-  isa => Str,
-
-  default => sub {
-    my ($self) = @_;
-
-    File::Spec->catfile(
-      $self->etc,
-      'plugins.conf'
-    )
+has path_to_plugins_cf => (
+  lazy      => 1,
+  is        => 'rwp',
+  isa       => Path,
+  coerce    => 1,
+  builder   => sub {
+    path( shift->etc .'/plugins.conf' )
   },
 );
 
 
-has 'core' => (
-  lazy => 1,
-
-  is  => 'ro',
-
+has core => (
+  lazy      => 1,
+  is        => 'ro',
   predicate => 'has_core',
   writer    => 'set_core',
-
-  isa => sub {
-    blessed $_[0] and $_[0]->isa('Bot::Cobalt::Conf::File::Core')
-      or die "core() should be a Bot::Cobalt::Conf::File::Core"
-  },
-
-  default => sub {
+  isa       => InstanceOf['Bot::Cobalt::Conf::File::Core'],
+  builder => sub {
     my ($self) = @_;
-
     Bot::Cobalt::Conf::File::Core->new(
-      debug => $self->debug,
-      path  => $self->path_to_core_cf,
+      debug     => $self->debug,
+      cfg_path  => $self->path_to_core_cf,
     )
   },
 );
 
-has 'channels' => (
-  lazy => 1,
-
-  is  => 'ro',
-
+has channels => (
+  lazy      => 1,
+  is        => 'ro',
   predicate => 'has_channels',
   writer    => 'set_channels',
-
-  isa => sub {
-    blessed $_[0] and $_[0]->isa('Bot::Cobalt::Conf::File::Channels')
-      or die "channels() should be a Bot::Cobalt::Conf::File:Channels"
-  },
-
-  default => sub {
+  isa       => InstanceOf['Bot::Cobalt::Conf::File::Channels'],
+  builder   => sub {
     my ($self) = @_;
-
     Bot::Cobalt::Conf::File::Channels->new(
-      debug => $self->debug,
-      path  => $self->path_to_channels_cf,
+      debug     => $self->debug,
+      cfg_path  => $self->path_to_channels_cf,
     )
   },
 );
 
-has 'plugins' => (
-  lazy => 1,
-
-  is  => 'ro',
-
+has plugins => (
+  lazy      => 1,
+  is        => 'ro',
   predicate => 'has_plugins',
   writer    => 'set_plugins',
-
-  isa => sub {
-    blessed $_[0] and $_[0]->isa('Bot::Cobalt::Conf::File::Plugins')
-      or die "plugins() should be a Bot::Cobalt::Conf::File::Plugins"
-  },
-
-  default => sub {
+  isa       => InstanceOf['Bot::Cobalt::Conf::File::Plugins'],
+  builder   => sub {
     my ($self) = @_;
-
     Bot::Cobalt::Conf::File::Plugins->new(
-      debug  => $self->debug,
-      path   => $self->path_to_plugins_cf,
-      etcdir => $self->etc,
+      debug     => $self->debug,
+      cfg_path  => $self->path_to_plugins_cf,
+      etcdir    => $self->etc,
     )
   },
 );
@@ -174,6 +127,8 @@ Bot::Cobalt::Conf - Bot::Cobalt configuration manager
   ## (Still need an etcdir)
   my $cfg = Bot::Cobalt::Conf->new(
     etc => $path_to_etc_dir,
+
+    # Default paths are probably fine (based on etc, above):
     path_to_core_cf     => $core_cf_path,
     path_to_channels_cf => $chan_cf_path,
     path_to_plugins_cf  => $plugins_cf_path,
