@@ -1,35 +1,31 @@
 package Bot::Cobalt::Conf::File::Core;
-our $VERSION = '0.016002';
-
-use 5.12.1;
-use strictures 1;
+$Bot::Cobalt::Conf::File::Core::VERSION = '0.017001';
+use v5.10;
+use strictures 2;
 
 use Carp;
+
+use Bot::Cobalt::Common ':types';
+
 use Moo;
-
-use Bot::Cobalt::Common qw/:types/;
-
 extends 'Bot::Cobalt::Conf::File';
 
-has 'language' => (
-  lazy => 1,
-  
-  is  => 'rwp',
-  isa => Str,
-  
-  default => sub {
+has language => (
+  lazy      => 1,
+  is        => 'rwp',
+  isa       => Str,
+  default   => sub {
     my ($self) = @_;
     $self->cfg_as_hash->{Language} // 'english' ;
   },
 );
 
-has 'paths' => (
-  lazy => 1,
-  
-  is  => 'rwp',
-  isa => HashRef,
-  
-  default => sub {
+has paths => (
+  lazy      => 1,
+  weak_ref  => 1,
+  is        => 'rwp',
+  isa       => HashRef,
+  default   => sub {
     my ($self) = @_;
     ref $self->cfg_as_hash->{Paths} eq 'HASH' ?
       $self->cfg_as_hash->{Paths}
@@ -37,25 +33,23 @@ has 'paths' => (
   },
 );
 
-has 'irc' => (
-  lazy => 1,
-  
-  is  => 'rwp',
-  isa => HashRef,
-  
-  default => sub {
+has irc => (
+  lazy      => 1,
+  weak_ref  => 1,
+  is        => 'rwp',
+  isa       => HashRef,
+  default   => sub {
     my ($self) = @_;
     $self->cfg_as_hash->{IRC}
   },
 );
 
-has 'opts' => (
-  lazy => 1,
-  
-  is  => 'rwp',
-  isa => HashRef,
-  
-  default => sub {
+has opts => (
+  lazy      => 1,
+  weak_ref  => 1,
+  is        => 'rwp',
+  isa       => HashRef,
+  default   => sub {
     my ($self) = @_;
     $self->cfg_as_hash->{Opts}
   },
@@ -64,7 +58,7 @@ has 'opts' => (
 around 'validate' => sub {
   my ($orig, $self, $cfg) = @_;
 
-  my $path = $self->path;
+  my $path = $self->cfg_path;
 
   for my $expected_hash (qw/ IRC Opts /) {
     unless (defined $cfg->{$expected_hash}) {
@@ -96,7 +90,7 @@ Bot::Cobalt::Conf::File::Core - Bot::Cobalt core config
 =head1 SYNOPSIS
 
   my $core_cfg = Bot::Cobalt::Conf::File::Core->new(
-    path => $path_to_cobalt_cf,
+    cfg_path => $path_to_cobalt_cf,
   );
   
   my $paths_hash = $core_cfg->paths;
