@@ -1,9 +1,7 @@
 package Bot::Cobalt::Core::Loader;
-our $VERSION = '0.016002';
-
-use 5.12.1;
-use strict;
-use warnings FATAL => 'all';
+$Bot::Cobalt::Core::Loader::VERSION = '0.017001';
+use v5.10;
+use strictures 2;
 
 use Carp;
 
@@ -11,6 +9,7 @@ use Scalar::Util qw/blessed/;
 
 use Try::Tiny;
 
+
 sub new { bless [], shift }
 
 sub is_reloadable {
@@ -19,9 +18,8 @@ sub is_reloadable {
   confess "is_reloadable() needs a plugin object"
     unless $obj and blessed $obj;
 
-  return if $obj->can('NON_RELOADABLE') and $obj->NON_RELOADABLE;
-
-  1
+  $obj->can('NON_RELOADABLE') && $obj->NON_RELOADABLE ?
+    undef : 1
 }
 
 sub module_path {
@@ -51,11 +49,12 @@ sub load {
   }
 
   my $obj;
-  try {
+  my $err; try {
     $obj = $module->new(@newargs)
   } catch {
-    croak "new() failed for $module: $_"
-  };
+    $err = "new() failed for $module: $_";
+    undef
+  } or confess $err;
 
   $obj // ()
 }
@@ -82,7 +81,7 @@ sub unload {
 
   ## Pretty much always returns success, on the theory that
   ## we did all we could from here.
-  return 1
+  1
 }
 
 1;
