@@ -1,11 +1,11 @@
 package Bot::Cobalt::Core::Role::Singleton;
-our $VERSION = '0.016002';
+$Bot::Cobalt::Core::Role::Singleton::VERSION = '0.017001';
 use Carp 'confess';
-use Moo::Role;
-use strict; no strict 'refs';
-use warnings FATAL => 'all';
+use strictures 2;
 
-use namespace::clean;
+use Moo::Role;
+
+no strict 'refs';
 
 sub instance {
   my $class = $_[0];
@@ -18,8 +18,7 @@ sub instance {
 
 sub has_instance {
   my $class = ref $_[0] || $_[0];
-  return unless ${$class.'::_singleton'};
-  1
+  !! ${$class.'::_singleton'};
 }
 
 sub clear_instance {
@@ -29,7 +28,7 @@ sub clear_instance {
 }
 
 sub is_instanced {
-  confess("is_instanced is deprecated; use has_instance")
+  confess "is_instanced is deprecated; use has_instance"
 }
 
 1;
