@@ -1,11 +1,10 @@
 package Bot::Cobalt::Core::Sugar;
-our $VERSION = '0.016002';
-
-use 5.10.1;
-use strictures 1;
+$Bot::Cobalt::Core::Sugar::VERSION = '0.017001';
+use strictures 2;
 use Carp;
 
-use base 'Exporter';
+use parent 'Exporter::Tiny';
+
 our @EXPORT = qw/
   core
   broadcast
@@ -121,7 +120,7 @@ L<Bot::Cobalt::Core::Role::IRC>
   my $irc_obj = irc_object($context);
 
 Retrieves the IRC object assigned to a context, which is a 
-L<POE::Component::IRC::State> instance unless L<Cobalt::IRC> has been 
+L<POE::Component::IRC::State> instance unless L<Bot::Cobalt::IRC> has been 
 subclassed or replaced.
 
 Wrapper for core->get_irc_object() -- see 
