@@ -1,123 +1,128 @@
 package Bot::Cobalt::DB;
-our $VERSION = '0.016002';
-
-## Simple interface to a DB_File
+$Bot::Cobalt::DB::VERSION = '0.017001';
 ## Uses proper retie-after-lock technique for locking
 
-use 5.12.1;
-use strictures 1;
+use v5.10;
+use strictures 2;
 use Carp;
 
-use Moo;
+use List::Objects::WithUtils;
 
 use DB_File;
 use Fcntl qw/:DEFAULT :flock/;
-
 use IO::File;
 
 use Bot::Cobalt::Serializer;
-use Bot::Cobalt::Common qw/:types/;
+use Bot::Cobalt::Common ':types';
 
-use Time::HiRes qw/sleep/;
+use Time::HiRes 'sleep';
 
 
-use namespace::clean -except => 'meta';
+use Moo;
 
-
-has 'File'  => (
-  is  => 'rw',
-  isa => Str,
-
-  required => 1
+has file => (
+  required  => 1,
+  is        => 'rw',
+  isa       => (Str | Object),
 );
+{ no warnings 'once'; *File = *file; }
 
-has 'Perms' => (
-  is => 'rw',
-
-  default => sub { 0644 },
+has perms => (
+  is        => 'rw',
+  builder   => sub { 0644 },
 );
+{ no warnings 'once'; *Perms = *perms; }
 
-has 'Raw'     => (
-  is  => 'rw',
-  isa => Bool,
-
-  default => sub { 0 },
+has raw => (
+  is        => 'rw',
+  isa       => Bool,
+  builder   => sub { 0 },
 );
+{ no warnings 'once'; *Raw = *raw; }
 
-has 'Timeout' => (
-  is  => 'rw',
-  isa => Num,
-
-  default => sub { 5 },
+has timeout => (
+  is        => 'rw',
+  isa       => Num,
+  builder   => sub { 5 },
 );
+{ no warnings 'once'; *Timeout = *timeout; }
 
-has 'Serializer' => (
-  lazy => 1,
-  is   => 'rw',
-  isa  => Object,
-
-  default => sub {
+has serializer => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => Object,
+  builder   => sub {
     Bot::Cobalt::Serializer->new(Format => 'JSON')
   },
 );
+{ no warnings 'once'; *Serializer = *serializer; }
 
 ## _orig is the original tie().
-has '_orig' => (
-  is  => 'rw',
-  isa => HashRef,
-
-  default => sub { {} },
+has _orig => (
+  is        => 'rw',
+  isa       => HashRef,
+  builder   => sub { {} },
 );
 
-## Tied is the re-tied DB hash.
-has 'Tied'  => (
-  is  => 'rw',
-  isa => HashRef,
-
-  default   => sub { {} },
+## tied is the re-tied DB hash.
+has tied  => (
+  is        => 'rw',
+  isa       => HashRef,
+  builder   => sub { {} },
 );
+{ no warnings 'once'; *Tied = *tied; }
 
-has '_lockFH' => (
-  lazy => 1,
-  is   => 'rw',
-  isa  => FileHandle,
-
-  predicate => 'has_LockFH',
-  clearer   => 'clear_LockFH',
+has _lockfh => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => FileHandle,
+  predicate => '_has_lockfh',
+  clearer   => '_clear_lockfh',
 );
 
 ## LOCK_EX or LOCK_SH for current open
-has '_lockmode' => (
-  lazy => 1,
-  is  => 'rw',
-
-  predicate => 'has_LockMode',
-  clearer   => 'clear_LockMode',
+has _lockmode => (
+  lazy      => 1,
+  is        => 'rw',
+  predicate => '_has_lockmode',
+  clearer   => '_clear_lockmode',
 );
 
 ## DB object.
-has 'DB'     => (
-  lazy => 1,
-  is   => 'rw',
-  isa  => Object,
-
+has DB     => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => Object,
   predicate => 'has_DB',
   clearer   => 'clear_DB',
 );
 
-has 'is_open' => (
-  is => 'rw',
-  isa => Bool,
-
-  default => sub { 0 },
+has is_open => (
+  is        => 'rw',
+  isa       => Bool,
+  default   => sub { 0 },
 );
 
 sub BUILDARGS {
   my ($class, @args) = @_;
-
-  @args == 1 ?
-    { File => $args[0] }
-    : { @args }
+  return +{ file => $args[0] } if @args == 1;
+  # Back-compat and I hate myself
+  my %opt = @args;
+  my $lower = array( qw/
+    File
+    Perms
+    Raw
+    Timeout
+    Serializer
+    Tied
+  / );
+  for my $key (%opt) {
+    if ( $lower->has_any(sub { $_ eq $key }) ) {
+      my $val = delete $opt{$key};
+      $opt{lc $key} = $val
+    }
+  }
+  \%opt
 }
 
 sub DESTROY {
@@ -130,10 +135,9 @@ sub dbopen {
   $args{lc $_} = delete $args{$_} for keys %args;
 
   ## per-open timeout was specified:
-  $self->Timeout( $args{timeout} )
-    if $args{timeout};
+  $self->timeout( $args{timeout} ) if $args{timeout};
 
-  if ( $self->is_open ) {
+  if ($self->is_open) {
     carp "Attempted dbopen() on already-open DB";
     return
   }
@@ -149,26 +153,26 @@ sub dbopen {
     $self->_lockmode(LOCK_EX);
   }
 
-  my $path = $self->File;
+  my $path = $self->file;
 
  ## proper DB_File locking:
   ## open and tie the DB to _orig
   ## set up object
   ## call a sync() to create if needed
   my $orig_db = tie %{ $self->_orig }, "DB_File", $path,
-      $fflags, $self->Perms, $DB_HASH
+      $fflags, $self->perms, $DB_HASH
       or confess "failed db open: $path: $!" ;
   $orig_db->sync();
 
-  ## dup a FH to $db->fd for _lockFH
+  ## dup a FH to $db->fd for _lockfh
   my $fd = $orig_db->fd;
   my $fh = IO::File->new("<&=$fd")
     or confess "failed dup in dbopen: $!";
 
   my $timer = 0;
-  my $timeout = $self->Timeout;
+  my $timeout = $self->timeout;
 
-  ## flock _lockFH
+  ## flock _lockfh
   until ( flock $fh, $lflags ) {
     if ($timer > $timeout) {
       warn "failed lock for db $path, timeout (${timeout}s)\n";
@@ -182,13 +186,13 @@ sub dbopen {
   }
 
   ## reopen DB to Tied
-  my $db = tie %{ $self->Tied }, "DB_File", $path,
-      $fflags, $self->Perms, $DB_HASH
+  my $db = tie %{ $self->tied }, "DB_File", $path,
+      $fflags, $self->perms, $DB_HASH
       or confess "failed db reopen: $path: $!";
 
   ## preserve db obj and lock fh
   $self->is_open(1);
-  $self->_lockFH( $fh );
+  $self->_lockfh($fh);
   $self->DB($db);
   undef $orig_db;
 
@@ -205,19 +209,19 @@ sub dbopen {
   $self->DB->filter_fetch_value(
     sub {
       s/\0$//;
-      $_ = $self->Serializer->ref_from_json($_)
-        unless $self->Raw;
+      $_ = $self->serializer->ref_from_json($_)
+        unless $self->raw;
     }
   );
   $self->DB->filter_store_value(
     sub {
-      $_ = $self->Serializer->json_from_ref($_)
-        unless $self->Raw;
+      $_ = $self->serializer->json_from_ref($_)
+        unless $self->raw;
       $_ .= "\0";
     }
   );
 
-  return 1
+  1
 }
 
 sub dbclose {
@@ -233,17 +237,17 @@ sub dbclose {
   }
 
   $self->clear_DB;
-  untie %{ $self->Tied }
-    or carp "dbclose: untie Tied: $!";
+  untie %{ $self->tied }
+    or carp "dbclose: untie tied: $!";
 
-  flock( $self->_lockFH, LOCK_UN )
+  flock( $self->_lockfh, LOCK_UN )
     or carp "dbclose: unlock: $!";
 
   untie %{ $self->_orig }
     or carp "dbclose: untie _orig: $!";
 
-  $self->clear_LockFH;
-  $self->clear_LockMode;
+  $self->_clear_lockfh;
+  $self->_clear_lockmode;
 
   $self->is_open(0);
 
@@ -255,7 +259,7 @@ sub get_tied {
   confess "attempted to get_tied on unopened db"
     unless $self->is_open;
 
-  return $self->Tied
+  $self->tied
 }
 
 sub get_db {
@@ -263,7 +267,7 @@ sub get_db {
   confess "attempted to get_db on unopened db"
     unless $self->is_open;
 
-  return $self->DB
+  $self->DB
 }
 
 sub dbkeys {
@@ -271,8 +275,9 @@ sub dbkeys {
   confess "attempted 'dbkeys' on unopened db"
     unless $self->is_open;
 
-  return wantarray ? (keys %{ $self->Tied })
-                   : scalar keys %{ $self->Tied };
+  wantarray ? 
+    (keys %{ $self->tied })
+    : scalar keys %{ $self->tied }
 }
 
 sub get {
@@ -282,7 +287,7 @@ sub get {
 
   return unless exists $self->Tied->{$key};
 
-  return $self->Tied->{$key}
+  $self->tied->{$key}
 }
 
 sub put {
@@ -290,7 +295,7 @@ sub put {
   confess "attempted 'put' on unopened db"
     unless $self->is_open;
 
-  return $self->Tied->{$key} = $value;
+  $self->tied->{$key} = $value
 }
 
 sub del {
@@ -298,11 +303,11 @@ sub del {
   confess "attempted 'del' on unopened db"
     unless $self->is_open;
 
-  return unless exists $self->Tied->{$key};
+  return unless exists $self->tied->{$key};
 
-  delete $self->Tied->{$key};
+  delete $self->tied->{$key};
 
-  return 1
+  1
 }
 
 sub dbdump {
@@ -312,7 +317,7 @@ sub dbdump {
   $format = 'YAMLXS' unless $format;
 
   ## shallow copy to drop tied()
-  my %copy = %{ $self->Tied };
+  my %copy = %{ $self->tied };
 
   my $dumper = Bot::Cobalt::Serializer->new( Format => $format );
 
@@ -335,14 +340,14 @@ Bot::Cobalt::DB - Locking Berkeley DBs with serialization
   ## ... perhaps in a Cobalt_register ...
   my $db_path = $core->var ."/MyDatabase.db";
   my $db = Bot::Cobalt::DB->new(
-    File => $db_path,
+    file => $db_path,
   );
 
   ## Open (and lock):
   $db->dbopen;
 
   ## Do some work:
-  $db->put("SomeKey", $some_deep_structure);
+  $db->put( SomeKey => $some_deep_structure );
 
   for my $key ($db->dbkeys) {
     my $this_hash = $db->get($key);
@@ -367,21 +372,21 @@ B<new()> is used to create a new Bot::Cobalt::DB object representing your
 Berkeley DB:
 
   my $db = Bot::Cobalt::DB->new(
-    File => $path_to_db,
+    file => $path_to_db,
 
    ## Optional arguments:
 
     # Database file mode
-    Perms => $octal_mode,
+    perms => $octal_mode,
 
     ## Locking timeout in seconds
     ## Defaults to 5s:
-    Timeout => 10,
+    timeout => 10,
 
     ## Normally, references are serialized transparently.
-    ## If Raw is enabled, no serialization filter is used and you're
+    ## If raw is enabled, no serialization filter is used and you're
     ## on your own.
-    Raw => 0,
+    raw => 0,
   );
 
 =head2 Opening and closing
@@ -447,8 +452,7 @@ The B<put> method adds an entry to the database:
 
   $db->put($key, $value);
 
-The value can be any data structure serializable by JSON::XS; that is to
-say, any shallow or deep data structure NOT including blessed references.
+The value can be any data structure serializable by L<JSON::MaybeXS>.
 
 Note that keys should be properly encoded:
 
@@ -483,7 +487,7 @@ You can serialize/export the entirety of the DB via B<dbdump>.
   my $yamlified = $db->dbdump('YAML');
   ## YAML::XS
   my $yamlified = $db->dbdump('YAMLXS');
-  ## JSON::XS
+  ## JSON::MaybeXS
   my $jsonified = $db->dbdump('JSON');
 
 See L<Bot::Cobalt::Serializer> for more on C<freeze()> and valid formats.
