@@ -1,15 +1,10 @@
 package Bot::Cobalt::Error;
-our $VERSION = '0.016002';
-
-use 5.12.1;
-use strictures 1;
+$Bot::Cobalt::Error::VERSION = '0.017001';
+use v5.10;
+use strictures 2;
 
 use Devel::StackTrace;
 
-use namespace::clean -except => 'meta';
-
-## Always 'use overload' *after* a namespace::clean
-
 use overload
   bool     => sub { 1 },
   '""'     => 'string',
