@@ -1,17 +1,17 @@
 package Bot::Cobalt::Frontend::RC;
-our $VERSION = '0.016002';
-
-use strictures 1;
+$Bot::Cobalt::Frontend::RC::VERSION = '0.017001';
+use strictures 2;
 
 use Carp;
-use Try::Tiny;
 
-use File::Spec;
-use Cwd ();
+use Cwd        ();
+use File::Spec ();
+
+use Try::Tiny;
 
 use Bot::Cobalt::Serializer;
 
-use base 'Exporter';
+use parent 'Exporter::Tiny';
 
 our @EXPORT_OK = qw/
   rc_read
@@ -23,21 +23,21 @@ sub rc_read {
   croak "rc_read needs a rcfile path" unless $rcfile;
 
   my $generic_crappy_err = sub {
-    warn(
+    warn
       "Errors reported during rcfile parse\n",
       "You may have an old, incompatible, or broken rcfile.\n",
       "Path: $rcfile\n",
-      "Try running cobalt2-installer\n"
-    );
+      "Try running cobalt2-installer\n" ;
   };
 
-  my $rc_h;
-  try {
-    $rc_h = Bot::Cobalt::Serializer->new->readfile($rcfile);
+  my $rc_err;
+  my $rc_h = try {
+    Bot::Cobalt::Serializer->new->readfile($rcfile)
   } catch {
     $generic_crappy_err->();
-    croak "Could not rc_read(); readfile said $_"
-  };
+    $rc_err = $_;
+    undef
+  } or croak "Could not rc_read(); readfile said $rc_err";
   
   unless ($rc_h && ref $rc_h eq 'HASH') {
     $generic_crappy_err->();
@@ -71,15 +71,11 @@ sub rc_write {
     VAR  => File::Spec->catdir( $basepath, 'var' ),
   };
 
-  ## Return $basepath on success, otherwise croak out.
-  try {
-    Bot::Cobalt::Serializer->new->writefile(
-      $rcfile, $rc_h
-    );
-    $basepath
-  } catch {
-    croak "rc_write() failure in call to Serializer; $rcfile $_"
-  }
+  Bot::Cobalt::Serializer->new->writefile(
+    $rcfile, $rc_h
+  );
+
+  $basepath
 }
 
 1;
