@@ -1,12 +1,11 @@
 package Bot::Cobalt::Frontend::Utils;
-our $VERSION = '0.016002';
+$Bot::Cobalt::Frontend::Utils::VERSION = '0.017001';
+use strictures 2;
 
 use 5.10.1;
-use strictures 1;
-
 use Carp;
 
-use base 'Exporter';
+use parent 'Exporter::Tiny';
 
 our @EXPORT_OK = qw/
   ask_yesno
