@@ -1,9 +1,7 @@
 package Bot::Cobalt::IRC;
-our $VERSION = '0.016002';
-
-use 5.10.1;
-use strictures 1;
-use Moo;
+$Bot::Cobalt::IRC::VERSION = '0.017001';
+use v5.10;
+use strictures 2;
 
 use Bot::Cobalt;
 use Bot::Cobalt::Common;
@@ -35,43 +33,35 @@ use POE qw/
 use IRC::Utils qw/ parse_mode_line /;
 
 
-use namespace::clean -except => 'meta';
+use Moo;
 
-
-has 'NON_RELOADABLE' => (
-  isa => Bool,
+has NON_RELOADABLE => (
   ## Well, really, it's sort-of unloadable.
   ##  ... but life usually sucks when you do.
   ## Call _set_NON_RELOADABLE if you really need to
-  is => 'rwp',
-
-  default => sub { 1 },
+  isa       => Bool,
+  is        => 'rwp',
+  default   => sub { 1 },
 );
 
 ## We keep references to our ircobjs; core tracks these also,
 ## but there is no guarantee that we're the only IRC plugin loaded.
-has 'ircobjs' => (
-  lazy => 1,
-  is   => 'rw',
-  isa  => HashRef,
-
-  default => sub { {} },
+has ircobjs => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => HashRef,
+  default   => sub { {} },
 );
 
-has 'flood' => (
-  is   => 'ro',
-  isa  => Object,
-  lazy => 1,
-
+has flood => (
+  is        => 'ro',
+  isa       => Object,
+  lazy      => 1,
   predicate => 'has_flood',
-
-  default => sub {
-    my ($self) = @_;
-
+  default   => sub {
     my $ccfg  = core->get_core_cfg;
     my $count = $ccfg->opts->{FloodCount} || 5;
     my $secs  = $ccfg->opts->{FloodTime}  || 6;
-
     Bot::Cobalt::IRC::FloodChk->new(
       count => $count,
       in    => $secs,
@@ -88,21 +78,18 @@ with 'Bot::Cobalt::IRC::Role::AdminCmds';
 sub Cobalt_register {
   my ($self, $core) = splice @_, 0, 2;
 
-  register($self, 'SERVER',
-    'all',
-  );
-
+  register($self, SERVER => 'all' );
   broadcast( 'initialize_irc' );
 
   ## Start a lazy cleanup timer for flood->expire
   $core->timer_set( 180,
-    { Event => 'ircplug_chk_floodkey_expire' },
+    +{ Event => 'ircplug_chk_floodkey_expire' },
     'IRCPLUG_CHK_FLOODKEY_EXPIRE'
   );
 
   logger->info("Loaded");
 
-  return PLUGIN_EAT_NONE
+  PLUGIN_EAT_NONE
 }
 
 sub Cobalt_unregister {
@@ -116,7 +103,7 @@ sub Cobalt_unregister {
 
   logger->debug("Clean unload");
 
-  return PLUGIN_EAT_NONE
+  PLUGIN_EAT_NONE
 }
 
 sub Bot_initialize_irc {
@@ -210,6 +197,8 @@ sub Bot_ircplug_connect {
     "Context $context; SSL $usessl ; V6 $use_v6"
   );
 
+  # FIXME at least optionally disable outgoing flood queue,
+  #   probably better to reimplement on top of IRC::FloodChk
   my %spawn_opts = (
       resolver => core->resolver,
 
@@ -389,7 +378,7 @@ sub _start {
     POE::Component::IRC::Plugin::CTCP->new(
       version  => "Bot::Cobalt ".core->version." (perl $^V) ".core->url,
       userinfo   => "I'm a teapot",
-      clientinfo => __PACKAGE__.'-'.$VERSION,
+      clientinfo => __PACKAGE__.'-'.(__PACKAGE__->VERSION // 'vcs'),
       source     => core->url,
     ),
   );
