@@ -1,14 +1,13 @@
 package Bot::Cobalt::IRC::Event::Kick;
-our $VERSION = '0.016002';
-
-use Moo;
-use strictures 1;
+$Bot::Cobalt::IRC::Event::Kick::VERSION = '0.017001';
+use strictures 2;
 use Bot::Cobalt::Common qw/:types/;
 
+use Moo;
 extends 'Bot::Cobalt::IRC::Event::Channel';
 
-has 'kicked' => ( is => 'rw', isa => Str, required => 1 );
-has 'reason' => ( is => 'rw', isa => Str, required => 1 );
+has kicked => ( is => 'rw', isa => Str, required => 1 );
+has reason => ( is => 'rw', isa => Str, required => 1 );
 
 1;
 __END__
