@@ -1,13 +1,13 @@
 package Bot::Cobalt::IRC::Event::Quit;
-our $VERSION = '0.016002';
+$Bot::Cobalt::IRC::Event::Quit::VERSION = '0.017001';
+use strictures 2;
 
-use Moo;
-use strictures 1;
 use Bot::Cobalt::Common qw/:types/;
 
+use Moo;
 extends 'Bot::Cobalt::IRC::Event';
 
-has 'reason' => ( 
+has reason => ( 
   lazy => 1, 
 
   is  => 'rw', 
@@ -16,7 +16,7 @@ has 'reason' => (
   default => sub {''},
 );
 
-has 'common' => ( 
+has common => ( 
   lazy => 1,
 
   is  => 'rw', 
