@@ -1,26 +1,22 @@
 package Bot::Cobalt::IRC::Event::Topic;
-our $VERSION = '0.016002';
-
-use Moo;
-use strictures 1;
+$Bot::Cobalt::IRC::Event::Topic::VERSION = '0.017001';
+use strictures 2;
 use Bot::Cobalt::Common qw/:types :string/;
 
+use Moo;
 extends 'Bot::Cobalt::IRC::Event::Channel';
 
-has 'topic' => (
-  required => 1,
-
-	is  => 'rw',
-  isa => Str, 
+has topic => (
+  required  => 1,
+  is        => 'rw',
+  isa       => Str, 
 );
 
-has 'stripped' => (
-  lazy => 1,
-
-  is  => 'ro', 
-  isa => Str, 
-
-  default => sub {
+has stripped => (
+  lazy      => 1,
+  is        => 'ro', 
+  isa       => Str, 
+  default   => sub {
     strip_color( strip_formatting( $_[0]->topic ) )
   },
 );
