@@ -1,49 +1,51 @@
 package Bot::Cobalt::IRC::FloodChk;
-our $VERSION = '0.016002';
-
+$Bot::Cobalt::IRC::FloodChk::VERSION = '0.017001';
 use Carp;
+use strictures 2;
+
+use Bot::Cobalt::Common ':types';
+
+use List::Objects::WithUtils;
+use Time::HiRes ();
+
 use Moo;
 
-use Bot::Cobalt::Common qw/:types/;
-
-use strictures;
-
-use Time::HiRes;
-
-## fqueue->{$context}->{$key} = []
-has 'fqueue' => ( is => 'rw', isa => HashRef,
-  default => sub { {} },
+## _fqueue->{$context}->{$key} = array()
+## FIXME Should probably be an obj ...
+has _fqueue => ( 
+  is      => 'rw',
+  lazy    => 1,
+  default => sub { +{} },
 );
 
-has 'count' => ( is => 'rw', isa => Num, required => 1 );
-has 'in'    => ( is => 'rw', isa => Num, required => 1 );
+has count => ( is => 'rw', isa => Num, required => 1 );
+has in    => ( is => 'rw', isa => Num, required => 1 );
 
 sub check {
   my ($self, $context, $key) = @_;
   return unless defined $context and defined $key; 
   
-  my $this_ref = ($self->fqueue->{$context}->{$key}//=[]);
+  my $thisq = $self->_fqueue->{$context}->{$key} //= array;
   
-  if (@$this_ref >= $self->count) {
-    my $oldest_ts = $this_ref->[0];
-    my $pending   = @$this_ref;
+  if ((my $pending = $thisq->count) >= $self->count) {
+
+    my $oldest_ts = $thisq->head;
     my $ev_c      = $self->count;
     my $ev_sec    = $self->in;
 
-    my $delayed = int(
-      ($oldest_ts + ($pending * $ev_sec / $ev_c) ) - Time::HiRes::time()
-    );
+    my $delayed =
+      ($oldest_ts + ($pending * $ev_sec / $ev_c) ) 
+      - Time::HiRes::time();
     
     ## Too many events in this time window:
     return $delayed if $delayed > 0;
-    
-    ## ...otherwise shift and push:
-    shift @$this_ref;
-  }
-  
-  ## Safe to push this ev.
-  push @$this_ref, Time::HiRes::time();
 
+    ## ...otherwise shift and continue:
+    $thisq->shift;
+  }
+
+  ## Safe to push this ev, no delay:
+  $thisq->push( Time::HiRes::time() );
   return 0
 }
 
@@ -52,30 +54,33 @@ sub clear {
   confess "clear() needs a context specified" 
     unless defined $context;
   
-  return unless exists $self->fqueue->{$context};
+  return unless exists $self->_fqueue->{$context};
   
-  return delete $self->fqueue->{$context}->{$key}
+  return delete $self->_fqueue->{$context}->{$key}
     if defined $key;
   
-  delete $self->fqueue->{$context}
+  delete $self->_fqueue->{$context}
 }
 
 sub expire {
   ## Clear keys when recent_event_time - time > $self->in
   my ($self) = @_;
-  CONTEXT: for my $context (keys %{ $self->fqueue } ) {
-    KEY: for my $key (keys %{ $self->fqueue->{$context} } ) {
-      my @events = @{ $self->fqueue->{$context}->{$key} };
-      my $latest_time = $events[-1] // next KEY;
+
+  CONTEXT: for my $context (keys %{ $self->_fqueue } ) {
+
+    KEY: for my $key (keys %{ $self->_fqueue->{$context} } ) {
+
+      my $events = $self->_fqueue->{$context}->{$key};
+      my $latest_time = $events->get(-1) // next KEY;
       
       if (Time::HiRes::time() - $latest_time > $self->in) {
         ## It's been more than ->in seconds since latest event was
         ## noted. We can clear() this entry.
         $self->clear($context, $key);
       }
-    } ## KEY
+    } # KEY
     
-    unless (keys %{ $self->fqueue->{$context} }) {
+    unless (keys %{ $self->_fqueue->{$context} }) {
       ## Nothing left for this context.
       $self->clear($context);
     }
