@@ -1,41 +1,36 @@
 package Bot::Cobalt::IRC::Message::Public;
-our $VERSION = '0.016002';
-
-use 5.10.1;
+$Bot::Cobalt::IRC::Message::Public::VERSION = '0.017001';
+use v5.10;
+use strictures 2;
 
 use Bot::Cobalt;
 use Bot::Cobalt::Common;
+use Scalar::Util 'blessed';
 
 use Moo;
-
-use Scalar::Util qw/blessed/;
-
 extends 'Bot::Cobalt::IRC::Message';
 
-has 'cmd' => (
-  lazy => 1,
-  is  => 'rw',
-  isa => Any,
-
+has cmd => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => Any,
   predicate => 'has_cmd',
   builder   => '_build_cmd',
 );
 
-has 'highlight' => (
-  lazy => 1,
-  is  => 'rw',
-  isa => Bool,
-
+has highlight => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => Bool,
   predicate => 'has_highlight',
   builder   => '_build_highlight',
 );
 
-has 'myself' => (
-  lazy => 1,
-  is  => 'rw',
-  isa => Str,
-
-  default => sub {
+has myself => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => Str,
+  builder   => sub {
     my ($self) = @_;
 
     require Bot::Cobalt::Core;
@@ -46,7 +41,7 @@ has 'myself' => (
   },
 );
 
-after 'message' => sub {
+after message => sub {
   my ($self, $value) = @_;
 
   if ($self->has_highlight) {
@@ -140,7 +135,7 @@ the B<message_array> leftwards to drop the command from
 B<message_array>.
 
 Normally this isn't used directly by plugins other
-than L<Cobalt::IRC>; a Message object handed off by a Bot_public_cmd_*
+than L<Bot::Cobalt::IRC>; a Message object handed off by a Bot_public_cmd_*
 event has this done for you already, for example.
 
 =head1 AUTHOR
