@@ -1,5 +1,6 @@
 package Bot::Cobalt::Plugin::Auth;
-our $VERSION = '0.016002';
+$Bot::Cobalt::Plugin::Auth::VERSION = '0.017001';
+
 
 ## "Standard" Auth module
 ##
@@ -47,7 +48,7 @@ use Bot::Cobalt::Common;
 use Bot::Cobalt::Error;
 use Bot::Cobalt::Serializer;
 
-use strictures 1;
+use strictures 2;
 
 use Storable qw/dclone/;
 
@@ -59,7 +60,6 @@ use File::Spec;
 sub ACCESS_LIST() { 0 }
 sub DB_PATH()     { 1 }
 
-use namespace::clean -except => 'meta';
 
 sub new {
   bless [
@@ -1565,7 +1565,7 @@ Alter a user's password manually. Only usable by superusers.
 Add or remove authorized masks for a particular user.
 
 You can add or remove masks for yourself at any time, so long as you 
-have at least L</DeletingUsers> level (see L</RequiredPrivs>). Altering 
+have at least B<DeletingUsers> level (see L</RequiredPrivs>). Altering 
 masks for other users requires a higher access level than theirs.
 
 Only one mask can be added or deleted at a time.
