@@ -1,17 +1,15 @@
 package Bot::Cobalt::Plugin::Games;
-our $VERSION = '0.016002';
+$Bot::Cobalt::Plugin::Games::VERSION = '0.017001';
 
+
+use strictures 2;
 use 5.10.1;
-use strict;
-use warnings;
 
 use Bot::Cobalt;
 use Object::Pluggable::Constants qw/ :ALL /;
 
 use Bot::Cobalt::Core::Loader;
 
-use namespace::clean -except => 'meta';
-
 sub new { bless {}, shift }
 
 sub Cobalt_register {
