@@ -1,5 +1,6 @@
 package Bot::Cobalt::Plugin::Games::Dice;
-our $VERSION = '0.016002';
+$Bot::Cobalt::Plugin::Games::Dice::VERSION = '0.017001';
+
 
 use 5.10.1;
 use strict;
@@ -43,7 +44,7 @@ sub execute {
 
       my $resp = "Rolled "
                  .color('bold', $n_dice)
-                 ." dice of "
+                 .($sides > 1 ? ' dice of ' : ' die of ')
                  .color('bold', $sides)
                  ." sides: " ;
 
