@@ -1,5 +1,6 @@
 package Bot::Cobalt::Plugin::Games::RockPaperScissors;
-our $VERSION = '0.016002';
+$Bot::Cobalt::Plugin::Games::RockPaperScissors::VERSION = '0.017001';
+
 
 use 5.10.1;
 use strict;
@@ -9,15 +10,16 @@ sub new { bless [], shift }
 
 sub execute {
   my ($self, $msg, $rps) = @_;
-  my $nick = $msg->src_nick//'';
+  my $nick = $msg->src_nick // '';
+  $rps = lc($rps // '');
 
   if      (! $rps) {
     return "What did you want to throw, ${nick}?"
-  } elsif ( ! grep { $_ eq lc($rps) } qw/rock paper scissors/ ) {
+  } elsif ( ! grep { $_ eq $rps } qw/rock paper scissors/ ) {
     return "${nick}: You gotta throw rock, paper, or scissors!"
   }
 
-  my $beats = {
+  state $beats = {
     scissors => 'paper',
     paper    => 'rock',
     rock     => 'scissors',
