@@ -1,13 +1,13 @@
 package Bot::Cobalt::Plugin::Master;
-our $VERSION = '0.016002';
+$Bot::Cobalt::Plugin::Master::VERSION = '0.017001';
+
 
 use 5.10.1;
-use strictures 1;
+use strictures 2;
 
 use Bot::Cobalt;
 use Bot::Cobalt::Common;
 
-use namespace::clean -except => 'meta';
 
 sub new { bless {}, shift }
 
