@@ -1,10 +1,9 @@
 package Bot::Cobalt::Plugin::RDB;
-our $VERSION = '0.016002';
+$Bot::Cobalt::Plugin::RDB::VERSION = '0.017001';
 
-## 'Random' DBs, often used for quotebots or random chatter
 
-use strictures 1;
-use 5.12.1;
+use strictures 2;
+use v5.10;
 
 use Bot::Cobalt;
 use Bot::Cobalt::Common;
@@ -20,7 +19,6 @@ use Try::Tiny;
 
 use POSIX ();
 
-use namespace::clean -except => 'meta';
 
 sub new {
   bless {
