@@ -1,7 +1,9 @@
 package Bot::Cobalt::Plugin::Rehash;
-our $VERSION = '0.016002';
+$Bot::Cobalt::Plugin::Rehash::VERSION = '0.017001';
 
-use 5.12.1;
+
+use strictures 2;
+use v5.10;
 
 use Bot::Cobalt;
 use Bot::Cobalt::Common;
@@ -11,9 +13,8 @@ use Bot::Cobalt::Lang;
 use File::Spec;
 use Try::Tiny;
 
-use strictures 1;
+use strictures 2;
 
-use namespace::clean -except => 'meta';
 
 sub new { bless [], shift }
 
