@@ -1,9 +1,10 @@
 package Bot::Cobalt::Plugin::Version;
-our $VERSION = '0.016002';
+$Bot::Cobalt::Plugin::Version::VERSION = '0.017001';
+
+
+use strictures 2;
 
 use 5.10.1;
-use strict;
-use warnings;
 
 use Bot::Cobalt;
 
@@ -11,8 +12,6 @@ use Object::Pluggable::Constants qw/ :ALL /;
 
 use Bot::Cobalt::Utils qw/ secs_to_str /;
 
-use namespace::clean -except => 'meta';
-
 sub new { bless [], shift  }
 
 sub Cobalt_register {
