@@ -1,8 +1,9 @@
 package Bot::Cobalt::Plugin::WWW;
-our $VERSION = '0.016002';
+$Bot::Cobalt::Plugin::WWW::VERSION = '0.017001';
 
+
+use strictures 2;
 use 5.10.1;
-use strictures 1;
 
 use Bot::Cobalt;
 use Bot::Cobalt::Common;
@@ -12,7 +13,6 @@ use POE qw/
   Component::Client::Keepalive
 /;
 
-use namespace::clean -except => 'meta';
 
 sub opts {
   my $opts = core->get_plugin_cfg($_[0])->{Opts};
