@@ -1,15 +1,12 @@
 package Bot::Cobalt::Serializer;
-our $VERSION = '0.016002';
-
-use 5.10.1;
-use strictures 1;
-
-use Moo;
+$Bot::Cobalt::Serializer::VERSION = '0.017001';
+use v5.10;
+use strictures 2;
 use Carp;
 
 ## These two must be present anyway:
 use YAML::XS ();
-use JSON::XS ();
+use JSON::MaybeXS ();
 
 use Fcntl qw/:flock/;
 
@@ -17,98 +14,80 @@ use Bot::Cobalt::Common qw/:types/;
 
 use Time::HiRes qw/sleep/;
 
+use Scalar::Util 'blessed';
 
-use namespace::clean -except => 'meta';
+use Moo;
 
 
-has 'Format' => (
-  is  => 'rw',
-  isa => Str,
-
-  default => sub { 'YAMLXS' },
-
-  trigger => sub {
+has Format => (
+  is        => 'rw',
+  isa       => Str,
+  builder   => sub { 'YAMLXS' },
+  trigger   => sub {
     my ($self, $format) = @_;
-
     $format = uc($format);
-
     confess "Unknown format $format"
       unless grep { $_ eq $format } keys %{ $self->_types };
-
     confess "Requested format $format but can't find a module for it"
       unless $self->_check_if_avail($format)
   },
 );
 
-has '_types' => (
-  lazy => 1,
-
-  is  => 'ro',
-  isa => HashRef,
-
-  default => sub {
-    {
+has _types => (
+  lazy      => 1,
+  is        => 'ro',
+  isa       => HashRef,
+  builder   => sub {
+    +{
       YAML   => 'YAML::Syck',
       YAMLXS => 'YAML::XS',
-      JSON   => 'JSON::XS',
+      JSON   => 'JSON::MaybeXS',
     }
   },
 );
 
-has 'yamlxs_from_ref' => (
-  is   => 'rw',
-  lazy => 1,
-
-  coerce => sub {
-    YAML::XS::Dump($_[0])
-  },
+has yamlxs_from_ref => (
+  is        => 'rw',
+  lazy      => 1,
+  coerce    => sub { YAML::XS::Dump($_[0]) },
 );
 
-has 'ref_from_yamlxs' => (
-  is   => 'rw',
-  lazy => 1,
-
-  coerce => sub {
-    YAML::XS::Load($_[0])
-  },
+has ref_from_yamlxs => (
+  is        => 'rw',
+  lazy      => 1,
+  coerce    => sub { YAML::XS::Load($_[0]) },
 );
 
-has 'yaml_from_ref' => (
-  is   => 'rw',
-  lazy => 1,
-
-  coerce => sub {
-    require YAML::Syck;
-    YAML::Syck::Dump($_[0])
-  },
+has yaml_from_ref => (
+  is        => 'rw',
+  lazy      => 1,
+  coerce    => sub { require YAML::Syck; YAML::Syck::Dump($_[0]) },
 );
 
-has 'ref_from_yaml' => (
-  is   => 'rw',
-  lazy => 1,
-
-  coerce => sub {
-    require YAML::Syck;
-    YAML::Syck::Load($_[0])
-  },
+has ref_from_yaml => (
+  is        => 'rw',
+  lazy      => 1,
+  coerce    => sub { require YAML::Syck; YAML::Syck::Load($_[0]) },
 );
 
-has 'json_from_ref' => (
-  is   => 'rw',
-  lazy => 1,
-
-  coerce => sub {
-    my $jsify = JSON::XS->new->allow_nonref;
+has json_from_ref => (
+  is        => 'rw',
+  lazy      => 1,
+  coerce    => sub {
+    my $jsify = JSON::MaybeXS->new(
+      utf8 => 1, allow_nonref => 1, convert_blessed => 1
+    );
     $jsify->utf8->encode($_[0]);
   },
 );
 
-has 'ref_from_json' => (
-  is   => 'rw',
-  lazy => 1,
-
+has ref_from_json => (
+  is        => 'rw',
+  lazy      => 1,
   coerce => sub {
-    my $jsify = JSON::XS->new->allow_nonref;
+    my $jsify = JSON::MaybeXS->new(
+      utf8 => 1, allow_nonref => 1
+    );
     $jsify->utf8->decode($_[0])
   },
 );
@@ -126,13 +105,11 @@ sub BUILDARGS {
   ## ->new( Format => 'JSON' )   ## --> to JSON
   ## - or -
   ## ->new( Format => 'YAML' ) ## --> to YAML1.0
-
   @args == 1 ? { Format => $args[0] } : { @args }
 }
 
 sub freeze {
   ## ->freeze($ref)
-  ## serialize arbitrary data structure
   my ($self, $ref) = @_;
   unless (defined $ref) {
     carp "freeze() received no data";
@@ -147,7 +124,6 @@ sub freeze {
 
 sub thaw {
   ## ->thaw($data)
-  ## deserialize data in specified Format
   my ($self, $data) = @_;
   unless (defined $data) {
     carp "thaw() received no data";
@@ -163,7 +139,6 @@ sub thaw {
 sub writefile {
   my ($self, $path, $ref, $opts) = @_;
   ## $serializer->writefile($path, $ref [, { Opts });
-  ## serialize arbitrary data and write it to disk
 
   if (!$path) {
     confess "writefile called without path argument"
@@ -179,7 +154,6 @@ sub writefile {
 sub readfile {
   my ($self, $path, $opts) = @_;
   ## my $ref = $serializer->readfile($path)
-  ## thaw a file into data structure
 
   if (!$path) {
     confess "readfile called without path argument";
@@ -200,12 +174,10 @@ sub version {
   return($module, $module->VERSION);
 }
 
-## Internals
 
 
 sub _check_if_avail {
   my ($self, $type) = @_;
-  ## see if we have this serialization method available to us
 
   my $module;
   return unless $module = $self->_types->{$type};
@@ -229,22 +201,26 @@ sub _read_serialized {
     $lock = $opts->{Locking} if defined $opts->{Locking};
   }
 
-  open(my $in_fh, '<:encoding(UTF-8)', $path)
-    or confess "open failed for $path: $!";
+  if (blessed $path && $path->can('slurp_utf8')) {
+    return $path->slurp_utf8
+  } else {
+    open(my $in_fh, '<:encoding(UTF-8)', $path)
+      or confess "open failed for $path: $!";
 
-  if ($lock) {
-    flock($in_fh, LOCK_SH)
-      or confess "LOCK_SH failed for $path: $!";
-   }
+    if ($lock) {
+      flock($in_fh, LOCK_SH)
+        or confess "LOCK_SH failed for $path: $!";
+     }
 
-  my $data = join '', <$in_fh>;
+    my $data = join '', <$in_fh>;
 
-  flock($in_fh, LOCK_UN) if $lock;
+    flock($in_fh, LOCK_UN) if $lock;
 
-  close($in_fh)
-    or carp "close failed for $path: $!";
+    close($in_fh)
+      or carp "close failed for $path: $!";
 
-  return $data
+    return $data
+  }
 }
 
 sub _write_serialized {
@@ -388,7 +364,7 @@ B<YAMLXS> - YAML1.1 via L<YAML::XS>  I<(default)>
 
 =item *
 
-B<JSON> - JSON via L<JSON::XS>
+B<JSON> - JSON via L<JSON::MaybeXS>
 
 =back
 
@@ -486,7 +462,7 @@ L<YAML::XS> -- YAML1.1: L<http://yaml.org/spec/1.1/>
 
 =item *
 
-L<JSON>, L<JSON::XS> -- JSON: L<http://www.json.org/>
+L<JSON>, L<JSON::MaybeXS> -- JSON: L<http://www.json.org/>
 
 =back
 
