@@ -1,28 +1,20 @@
 package Bot::Cobalt::Timer;
-our $VERSION = '0.016002';
-
-use strictures 1;
-use 5.10.1;
-
+$Bot::Cobalt::Timer::VERSION = '0.017001';
+use strictures 2;
 use Carp;
+
+use Bot::Cobalt::Common ':types';
+
 use Moo;
 
-use Bot::Cobalt::Common qw/:types/;
-
-
-use namespace::clean -except => 'meta';
-
 ## It's possible to pass in a different core.
 ## (Allows timers to fire against different syndicators if needed)
-has 'core'  => (
-  lazy => 1,
-
-  is  => 'rw',
-  isa => Object,
-
-  default => sub {
+has core  => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => Object,
+  builder   => sub {
     require Bot::Cobalt::Core;
-
     Bot::Cobalt::Core->instance 
       || die "Cannot find active Bot::Cobalt::Core instance"
   },
@@ -31,103 +23,82 @@ has 'core'  => (
 ## May have a timer ID specified at construction for use by
 ## timer pool managers; if not, creating IDs is up to them.
 ## (See ::Core::Role::Timers)
-has 'id' => (
-  lazy => 1,
-
-  is  => 'rw',
-  isa => Str,
-
+has id => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => Str,
   predicate => 'has_id'
 );
 
 ## 'at' is set regardless of whether delay()/at() is used
 ## (or 0 if none is ever set)
-has 'at'    => (
-  lazy => 1,
-
-  is  => 'rw',
-  isa => Num,
-
-  default => sub { 0 },
+has at => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => Num,
+  builder   => sub { 0 },
 );
 
-has 'delay' => (
-  lazy => 1,
-
-  is  => 'rw',
-  isa => Num,
-
+has delay => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => Num,
   predicate => 'has_delay',
   clearer   => 'clear_delay',
-
-  default   => sub { 0 },
-
+  builder   => sub { 0 },
   trigger   => sub {
     my ($self, $value) = @_;
     $self->at( time() + $value );
   },
 );
 
-has 'event' => (
-  lazy => 1,
-
-  is  => 'rw',
-  isa => Str,
-
+has event => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => Str,
   predicate => 'has_event',
 );
 
-has 'args'  => (
-  lazy => 1,
-
-  is  => 'rw',
-  isa => ArrayRef,
-
-  default => sub { [] },
+has args  => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => ArrayRef,
+  builder   => sub { [] },
 );
 
-has 'alias' => (
-  is  => 'rw',
-  isa => Str,
-
-  default => sub { scalar caller },
+has alias => (
+  is        => 'rw',
+  isa       => Str,
+  builder   => sub { scalar caller },
 );
 
-has 'context' => (
-  lazy => 1,
-
-  is  => 'rw',
-  isa => Str,
-
+has context => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => Str,
   predicate => 'has_context',
-
-  default   => sub { 'Main' },
+  builder   => sub { 'Main' },
 );
 
-has 'text'    => (
-  lazy => 1,
-
-  is  => 'rw',
-  isa => Str,
-
+has text    => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => Str,
   predicate => 'has_text'
 );
 
-has 'target'  => (
-  lazy => 1,
-  is  => 'rw',
-  isa => Str,
-
+has target  => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => Str,
   predicate => 'has_target'
 );
 
-has 'type'  => (
-  lazy => 1,
-
-  is  => 'rw',
-  isa => Str,
-
-  default => sub {
+has type  => (
+  lazy      => 1,
+  is        => 'rw',
+  isa       => Str,
+  builder   => sub {
     my ($self) = @_;
 
     if ($self->has_context && $self->has_target) {
@@ -138,7 +109,6 @@ has 'type'  => (
       return 'event'
     }
   },
-
   coerce => sub {
     $_[0] =~ /message|privmsg/i ? 'msg' : lc($_[0]) ;
   },
