@@ -1,14 +1,14 @@
 package Bot::Cobalt::Utils;
-our $VERSION = '0.016002';
-
-use 5.10.1;
-use strict;
-use warnings;
+$Bot::Cobalt::Utils::VERSION = '0.017001';
+use v5.10;
+use strictures 2;
 use Carp;
 
+use Scalar::Util 'reftype';
+
 use App::bmkpasswd ();
 
-use base 'Exporter';
+use parent 'Exporter::Tiny';
 
 our @EXPORT_OK = qw/
   secs_to_str
@@ -91,7 +91,7 @@ sub rplprintf {
     my %args = @_;
     %vars = ( %default_fmt_vars, %args );
   } else {
-    if (ref $_[0] eq 'HASH') {
+    if (reftype $_[0] eq 'HASH') {
       %vars = ( %default_fmt_vars, %{$_[0]} );
     } else {
       confess "rplprintf() expects a hash"
